@@ -1,8 +1,7 @@
 import sys
 
 from cleo import Application
-
-from rgov.commands import check, search, initialize, check_daemon, run
+from rgov.commands import check, check_daemon, initialize, run, search
 
 commands = [
     check.CheckCommand(),
@@ -16,8 +15,10 @@ application = Application()
 
 [application.add(command) for command in commands]
 
+
 def main():
     application.run()
 
+
 if __name__ == "__main__":
     main()
